<?php

namespace Drupal\views_field_view_ll\Plugin\views\field;

use Drupal\views\ResultRow;
use Drupal\views_field_view\Plugin\views\field\View;

/**
 * @ViewsField("view_lazy_loaded")
 */
class LazyLoadedView extends View {

  /**
   * {@inheritdoc}
   */
  public function render(ResultRow $values) {
    static $running = [];
    $view_id = $this->options['view'] ?? '';
    $display_id = $this->options['display'] ?? '';

    if (!$view_id || !$display_id) {
      $output = $this->t('Could not detect the view to embed or the selected display!');
      $values->{'views_field_view_' . $this->options['id']} = $output;
      return $output;
    }

    // Protect against the evil / recursion.
    // Set the variable for yourself, this is not for the normal "user".
    if (!empty($running[$view_id][$display_id]) && $this->config->get('evil')) {
      $output = $this->t('Recursion, stop!');
      $values->{'views_field_view_' . $this->options['id']} = $output;
      return $output;
    }

    $running[$view_id][$display_id] = TRUE;
    $args = [];
    // Only perform this loop if there are actually arguments present.
    if (!empty($this->options['arguments'])) {
      // Create an array of tokens.
      foreach ($this->splitTokens($this->options['arguments']) as $token) {
        $args[] = $this->getTokenValue($token, $values, $this->view);
      }
    }
    $route_parameters = [
      'view' => $view_id,
      'display_id' => $display_id,
      'nojs' => 'nojs',
    ];
    $options = [
      'query' => \Drupal::requestStack()->getCurrentRequest()->query->all(),
    ];
    $options['query'] += ['vallb_views_arguments' => $args];
    $ajax_identifier = $view_id . ':' . $display_id;
    $output = [
      '#theme' => 'vallb',
      '#ajax_identifier' => $ajax_identifier,
      '#route_parameters' => $route_parameters,
      '#route_options' => $options,
      '#route_name' => 'vallb.lazy_builder',
      '#view' => $this->view,
      '#view_display_id' => $display_id,
    ];

    $running[$view_id][$display_id] = FALSE;

    if (!empty($output)) {
      // Add the rendered output back to the $values object,
      // so it is available in $view->result objects.
      $values->{'views_field_view_' . $this->options['id']} = $output;
    }

    return $output;
  }

}
